This is the link to the VHS repository: https://github.com/charmbracelet/vhs?tab=readme-ov-file#installation

Check the `demo.tape` script in this directory. Make any adjustments, add any screens you want. Then run `vhs demo.tape` in this directory. It will record the screen and output the GIF to the `assets` directory.